==> guava-libraries_18.0.orig.tar.xz: guava-libraries-v18.0/guava-gwt/test/com/google/common/primitives/IntsTest_gwt.java <==
/*
 * Copyright (C) 2008 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.common.primitives;
public class IntsTest_gwt extends com.google.gwt.junit.client.GWTTestCase {
@Override public String getModuleName() {
  return "com.google.common.primitives.testModule";
}
public void testAsListEmpty() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsListEmpty();
}

public void testAsList_isAView() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_isAView();
}

public void testAsList_subList_toArray_roundTrip() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_subList_toArray_roundTrip();
}

public void testAsList_toArray_roundTrip() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_toArray_roundTrip();
}

public void testCheckedCast() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testCheckedCast();
}

public void testCompare() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testCompare();
}

public void testConcat() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testConcat();
}

public void testContains() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testContains();
}

public void testEnsureCapacity() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testEnsureCapacity();
}

public void testEnsureCapacity_fail() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testEnsureCapacity_fail();
}

public void testHashCode() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testHashCode();
}

public void testIndexOf() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testIndexOf();
}

public void testIndexOf_arrayTarget() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testIndexOf_arrayTarget();
}

public void testJoin() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testJoin();
}

public void testLastIndexOf() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testLastIndexOf();
}

public void testLexicographicalComparator() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testLexicographicalComparator();
}

public void testMax() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMax();
}

public void testMax_noArgs() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMax_noArgs();
}

public void testMin() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMin();
}

public void testMin_noArgs() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMin_noArgs();
}

public void testSaturatedCast() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testSaturatedCast();
}

public void testStringConverter_convert() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_convert();
}

public void testStringConverter_convertError() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_convertError();
}

public void testStringConverter_nullConversions() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_nullConversions();
}

public void testStringConverter_reverse() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_reverse();
}

public void testToArray() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray();
}

public void testToArray_threadSafe() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_threadSafe();
}

public void testToArray_withConversion() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_withConversion();
}

public void testToArray_withNull() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_withNull();
}

public void testTryParse() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse();
}
}

==> guava-libraries_29.0.orig.tar.xz: guava-libraries-29.0/guava-gwt/test/com/google/common/primitives/IntsTest_gwt.java <==
/*
 * Copyright (C) 2008 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.common.primitives;
public class IntsTest_gwt extends com.google.gwt.junit.client.GWTTestCase {
@Override public String getModuleName() {
  return "com.google.common.primitives.testModule";
}
public void testAsListEmpty() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsListEmpty();
}

public void testAsList_isAView() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_isAView();
}

public void testAsList_subList_toArray_roundTrip() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_subList_toArray_roundTrip();
}

public void testAsList_toArray_roundTrip() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testAsList_toArray_roundTrip();
}

public void testByteArrayRoundTrips() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testByteArrayRoundTrips();
}

public void testCheckedCast() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testCheckedCast();
}

public void testCompare() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testCompare();
}

public void testConcat() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testConcat();
}

public void testConstrainToRange() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testConstrainToRange();
}

public void testContains() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testContains();
}

public void testEnsureCapacity() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testEnsureCapacity();
}

public void testEnsureCapacity_fail() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testEnsureCapacity_fail();
}

public void testFromByteArray() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testFromByteArray();
}

public void testFromByteArrayFails() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testFromByteArrayFails();
}

public void testFromBytes() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testFromBytes();
}

public void testHashCode() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testHashCode();
}

public void testIndexOf() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testIndexOf();
}

public void testIndexOf_arrayTarget() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testIndexOf_arrayTarget();
}

public void testJoin() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testJoin();
}

public void testLastIndexOf() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testLastIndexOf();
}

public void testLexicographicalComparator() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testLexicographicalComparator();
}

public void testMax() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMax();
}

public void testMin() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testMin();
}

public void testReverse() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testReverse();
}

public void testReverseIndexed() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testReverseIndexed();
}

public void testSaturatedCast() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testSaturatedCast();
}

public void testSortDescending() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testSortDescending();
}

public void testSortDescendingIndexed() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testSortDescendingIndexed();
}

public void testStringConverter_convert() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_convert();
}

public void testStringConverter_convertError() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_convertError();
}

public void testStringConverter_nullConversions() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_nullConversions();
}

public void testStringConverter_reverse() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testStringConverter_reverse();
}

public void testToArray() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray();
}

public void testToArray_threadSafe() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_threadSafe();
}

public void testToArray_withConversion() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_withConversion();
}

public void testToArray_withNull() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToArray_withNull();
}

public void testToByteArray() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testToByteArray();
}

public void testTryParse() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse();
}

public void testTryParse_radix() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse_radix();
}

public void testTryParse_radixTooBig() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse_radixTooBig();
}

public void testTryParse_radixTooSmall() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse_radixTooSmall();
}

public void testTryParse_withNullGwt() throws Exception {
  com.google.common.primitives.IntsTest testCase = new com.google.common.primitives.IntsTest();
  testCase.testTryParse_withNullGwt();
}
}
